@@ -5,37 +5,13 @@ flexibility or having new widgets.
 """
 
 import io
+from pylejandria.tools import pretty_dict, pretty_list, pair
+from pylejandria.constants import FILETYPES, PHONE_EXTENSIONS
+import re
 import tkinter as tk
 from tkinter import ttk
 from tkinter import filedialog
-from typing import Any
-
-FILETYPES = {
-    'PDF': ('.pdf',),
-    'JPEG': ('.jpg', '.jpeg', '.jpe', '.jfif'),
-    'PNG': ('.png',),
-    'TIFF': ('.tiff', '.tif'),
-    'ICO': ('.ico',),
-    'WORD': ('.docx', '.docm', '.dotx', '.dotm'),
-    'EXCEL': ('.csv', '.xlsx', '.xlsm', '.xltx', '.xltm', '.xlsb', '.xlam'),
-    'POWERPOINT': (
-        '.pptx', '.pptm', '.potx', '.potm', '.ppam', '.ppsx', '.ppsm',
-        '.sldx', '.sldm', '.thmx'
-    ),
-    'VIDEO': (
-        '.asf', '.lsf', '.asx', '.bik', '.smk', '.div', '.divx', '.dvd',
-        '.wob', '.ivf', '.m1v', '.mp2v', '.mp4', '.mpa', '.mpe', '.mpeg',
-        '.mpg', '.mpv2', '.mov', '.qt', '.qtl', '.rpm', '.wm', '.wmv', '.avi'
-    ),
-    'AUDIO': (
-        '.mp3', '.mid', '.midi', '.wav', '.wma', '.cda', '.ogg', '.ogm',
-        '.aac', '.adt', '.adts', '.ac3', '.flac', '.mp4', '.aym'
-    ),
-    'IMAGE': (
-        '.bmp', '.gif', '.jpeg', '.jpg', '.png', '.psd', '.ai', '.cdr',
-        '.svg', '.raw', '.nef'
-    )
-}
+from typing import Any, Callable
 
 
 class Window(tk.Tk):
@@ -214,7 +190,9 @@ class Hierarchy(tk.Frame):
                         self.build(item, row_name)
                     else:
                         try:
-                            self.treeview.insert(row_name, 'end', item, text=item)
+                            self.treeview.insert(
+                                row_name, 'end', item, text=item
+                            )
                         except tk.TclError:
                             print(row_name, item, type(item))
             else:
@@ -223,6 +201,61 @@ class Hierarchy(tk.Frame):
             self.index += 1
 
 
+class PhoneEntry(tk.Frame):
+    def __init__(
+        self, master: tk.Widget,
+        text: str | None=None, extensions: bool=True,
+        button: str | None=None, command: Callable=lambda: None,
+        **kwargs
+    ):
+        """
+        Compound widget to make a phone entry, with extension if wanted.
+        Params:
+            master: parent widget.
+            text: optional label at the beginning.
+            extensions: optional if code extensions.
+            button: optional button name.
+            command: optional command for button.
+        """
+        super().__init__(master)
+
+        self.extension = extensions
+        self.pattern = kwargs.get('regex', '.*')
+        self.is_valid = False
+
+        if text is not None:
+            tk.Label(
+                self, text=text
+            ).grid(row=0, column=0)
+        if extensions is True:
+            self.extension_combobox = ttk.Combobox(
+                self, values=PHONE_EXTENSIONS, width=5, state='readonly'
+            )
+            self.extension_combobox.current(0)
+            self.extension_combobox.grid(row=0, column=1)
+        self.number_entry = tk.Entry(self)
+        self.number_entry.grid(row=0, column=2)
+        self.number_entry.bind('<Key>', self.update_config)
+        if button is not None:
+            tk.Button(self, text=button, command=command).grid(row=0, column=3)
+
+    def get(self) -> None:
+        if not self.extension:
+            return self.number_entry.get()
+        return self.extension_combobox.get() + self.number_entry.get()
+
+    def update_config(self, event) -> None:
+        full_number = self.get() + event.char
+        self.number_entry['fg'] = 'black'
+        self.is_valid = re.match(self.pattern, full_number) is not None
+
+    def validate(self, *args) -> None:
+        if self.is_valid is True:
+            self.number_entry['fg'] = '#00ff00'
+        else:
+            self.number_entry['fg'] = '#ff0000'
+
+
 def filetypes(
     *types: list[str],
     all_files: bool | None=True
@@ -256,3 +289,85 @@ def ask(property: str, *types, **kwargs) -> str:
     if types:
         kwargs['filetypes'] = filetypes(*types)
     return func(**kwargs)
+
+
+def style(
+    master: tk.Widget, config: dict, name: str | None=None,
+    alias: str | None=None, from_: Any | None=tk,
+    widget: Any | None=None, **kwargs
+) -> tk.Widget | Any:
+    """
+    Function to apply style to widgets, it can be already existing widgets or
+    it can be indicated which want to be created.
+    Params:
+        master: parent widget.
+        config: dictionary with all the properties of the widgets, each element
+                of the dictionary must be another dictionary with name equal
+                to the name of the widget or an alias and then its properties.
+        name:   name of the widget to create, if not given then widget argument
+                must be provided.
+        alias:  name is used to know which widget is wanted, but alias
+                references the name of the attribute from the config argument.
+        from_:  module where to import the widget.
+        widget: if there is a widget already created it can be also styled, if
+                provided then name, master and from_ are not needed.
+
+    """
+    if alias is None:
+        alias = name
+    all_config = config.get(alias) | kwargs
+    if init_config := all_config.get('init', {}):
+        all_config.pop('init')
+    if widget is None:
+        widget = getattr(from_, name)(master, **init_config)
+    for key, value in all_config.items():
+        widget[key] = value
+    return widget
+
+def get_chunk(a: str, b: str, lines: list[str]) -> tuple[list[str], list[str]]:
+    if b is None:
+        return [], lines
+    start = lines.index(a)
+    end = lines.index(b, start+1)
+    return lines[end:], [line.strip() for line in lines[start:end]]
+
+def load(filename: str, tab: str | None='    ') -> tk.Widget:
+    """
+    Loads a file with extension *.tk and builds all the widgets, the idea is
+    to have a setup more or less like QML, a cascade of widgets, is meant to
+    simple UI.
+    Params:
+        filename: path of the *.tk file.
+
+    Returns:
+        tk.Widget: the builded widget from the given file.
+    """
+    with open(filename, 'r') as f:
+        lines = f.read().split('\n')
+        widget_names = [line for line in lines if not ':' in line]
+
+    widgets = []
+    chunks = []
+
+    for name in widget_names:
+        try:
+            widget = getattr(tk, name.strip())
+        except AttributeError:
+            widget = eval(name.strip())
+        if name.count(tab) == 0:
+            widget()
+        widgets.append(widget)
+
+    for a, b in pair(widget_names + [None], 2):
+        lines, chunk = get_chunk(a, b, lines)
+        widget = {'widget': chunk.pop(0)}
+
+        for item in chunk:
+            key, value = item.split(': ', maxsplit=1)
+            widget[key] = value
+        chunks.append(widget)
+    
+    pretty_list(chunks)
+
+    # for i in range(len(widgets)-1):
+    #     widget1, info1 = widgets[i],
