@@ -8,11 +8,10 @@ import img2pdf
 import math
 import os
 import sys
-from typing import Any, Iterable
+from typing import Any, Iterable, Generator
+from pylejandria.constants import Number
 from pylejandria.gui import ask
 
-Number = float | int
-
 
 def center(text: str, space: int) -> str:
     """
@@ -309,6 +308,64 @@ def dict_get(dictionary: dict, key: Any, default: Any=None) -> Any:
     return default
 
 
+def make_dirs(folders: Iterable[str], root: str | None='') -> None:
+    """
+    Creates the corresponding directories and manages the existing conflict.
+    Params:
+        folders: list of folders to create if possible.
+        root: optional root of folder.
+    """
+    for folder in folders:
+        if not os.path.isdir(f'{root}\{folder}'):
+            os.mkdir(f'{root}\{folder}')
+
+
+def dict_zip(*dicts, strict: bool | None=False) -> None:
+    """
+    Creates a generator to iterate each key, value of each dictionary, just as
+    regular zip to lists.
+    Params:
+        dicts:  all the dictionaries to zip.
+        strict: raise an error if any dictionary is exhausted. 
+    """
+    for items in zip(*[dict_.items() for dict_ in dicts], strict=strict):
+        yield [[element for element in item] for item in items]
+
+def pair(items: list[Any], length: int) -> Generator:
+    """
+    Pairs n-elements from the list and yields it.
+    Example:
+        a = [1, 2, 3, 4, 5, 6]
+        for a, b, c, c in pair(a, 4):
+            print(a, b, c, d)
+        >>> (1, 2, 3, 4)
+        >>> (2, 3, 4, 5)
+        >>> (3, 4, 5, 6)
+    Params:
+        items: list to be paired.
+        length: length of the pairs.
+    """
+    for i in range(len(items)-length-1):
+        yield items[i:i+length]
+
+
 if __name__ == '__main__':
-    a = [1, 1, 1, 1, 1]
-    print(all_are(a, 1))
+    d1 = {
+        'a1': 1,
+        'a2': 2,
+        'a3': 3
+    }
+    d2 = {
+        'b4': 4,
+        'b5': 5,
+        'b6': 6,
+        'b7': 7
+    }
+    d3 = {
+        'c8': 8,
+        'c9': 9,
+        'c10': 10
+    }
+
+    for args in dict_zip(d1, d2, d3):
+        print(args)
